@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006,2007,2008,2009 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -33,17 +33,18 @@
 #include "utils.h"
 #include "btio.h"
 #include "conf.h"
+#include "dispatcher.h"
 
 #define PAUSE_TIME 1
 
-extern int handle_command(char* cmd);
-extern int serverMode;  // No AT command in serverMode
 extern char tmp[MAXMAXLEN];
 
 int useQuestionInCLCC = 0;
 
 void sendSyncCommand(char *bytes, char *answer, int size, char *expect) 
 {
+        DEBUG2("sendSyncCommand >%s<\n", bytes);
+	
 	// initial timeout was 5
         bt_put_command (bytes, answer, size, 40, expect); 
 }
@@ -53,7 +54,12 @@ int sendCMER(int onOff)
 	char answer[100];
         char cmd[64];
 	
-        strcpy(cmd,getAT_CMER(onOff));
+	char * cmer = getAT_CMER(onOff);
+	if (cmer == NULL) return EXIT_NOK;
+	
+        strcpy(cmd,cmer);
+	free(cmer);
+	
         strcat(cmd,"\r");
         //sendSyncCommand(cmd, answer, sizeof(answer), NULL);
 	bt_put_command (cmd, answer, sizeof(answer), 10, NULL);
@@ -72,7 +78,7 @@ static int sendCKPD(char *key)
         char ckpd[MAXCKPDLEN];
 
         if (key == NULL || key[0] == '\0') {
-        	logger("DEBUG","Empty symbol in sendCKPD()");
+        	logger("DBG","Empty symbol in sendCKPD()");
                 return EXIT_NOK;
         }
         DEBUG2("sendCKPD >%s<", key);
@@ -81,13 +87,13 @@ static int sendCKPD(char *key)
 
         int model = getModel();
 
-        if (model == MODEL_SE || model == MODEL_SIEMENS) {  // SE-K700, Siemens-S55
-        	// If we send AT+CKPD=X
+        if (model == MODEL_SE || model == MODEL_SIEMENS) {  // SE-K700, Siemens-S55 
+		// If we send AT+CKPD=X
                 // SE phone will replay
                 // OK
                 // +CKEV: X,1
                 // +CKEV: X,0
-                // And wee need to filter out that CKEVs
+                // And we need to filter out that CKEVs
                 char expect[16];
                 strcpy(expect, DEF_CKEV);
                 strcat(expect, " ");
@@ -107,7 +113,7 @@ static int sendCKPD(char *key)
                 // Filter out button up
                 char *ptr = strstr(answer, expect);
                 if(ptr == NULL) {
-                	logger("DEBUG","cant find button up event");
+                	logger("DBG","cant find button up event");
                 } else {
                 	int z;
                 	int l = strlen(expect);
@@ -130,7 +136,7 @@ static int sendCKPD(char *key)
                 strcat(expect, ",1");
                 ptr = strstr(answer, expect);
                 if(ptr == NULL) {
-                	logger("DEBUG","cant find button down event");
+                	logger("DBG","cant find button down event");
                 } else {
 			int z;
                 	int l = strlen(expect);
@@ -145,52 +151,36 @@ static int sendCKPD(char *key)
         	sendSyncCommand(ckpd, answer, sizeof(answer), NULL);
         }
 	
-        return handle_command(answer);
+	parseCommand(answer);
+
+        return EXIT_OK;
 }
 
-
+//
+// Should be used in AT mode only
+// 
 int sendSeq(const char *seq) 
 {
-	if (getUseScreen() == 0) return EXIT_OK;
-
-        if (seq == NULL) {
-        	logger("DEBUG","sendSeq() input is NULL");
-                return EXIT_OK;
-        }
+	if (getUseScreen() == 0 || seq == NULL) return EXIT_OK;
 
         DEBUG2("sendSeq() >%s<", seq);
 
-        if (serverMode > 0) {
-        	logger("ERROR", "Can not use SendCKPD() in Server style");
-                return EXIT_OK;
-        } else {
-        	char* copy = strdup(seq);
+        char* copy = strdup(seq);
 
-                char *bufPtr;
-                char *ckpd = strtok_r(copy," ",&bufPtr);
+        char *bufPtr = NULL;
+        char *ckpd = strtok_r(copy," ",&bufPtr);
 
-                while (ckpd != NULL) {
-                	//DEBUG2("NEXT sendSeq()->sendCKPD()>%s<", ckpd);
+        while (ckpd != NULL) {
+        	//DEBUG2("NEXT sendSeq()->sendCKPD()>%s<", ckpd);
         
-                        if (strcmp(ckpd, PAUSE_STR)==0) {
-                        	// Just wait a bit
-                                //logger("DEBUG","sendSeq() PAUSE");
-                
-                                sleep(PAUSE_TIME);
-                        } else {
-                        	
-                                int ret = sendCKPD(ckpd);
-                                if (ret == EXIT_DISCON || ret == EXIT_ABORT) {
-                                	logger("WARNING", "Got disconnect or abort...");
-                                
-                                        free(copy);
-                                        return ret;
-                                }
-                        }
-                        ckpd = strtok_r(NULL," ",&bufPtr);
+                if (strcmp(ckpd, PAUSE_STR)==0) {
+                        sleep(PAUSE_TIME);	// Just wait a bit
+                } else {
+                        sendCKPD(ckpd);
                 }
-                free(copy);
+                ckpd = strtok_r(NULL," ",&bufPtr);
         }
+        free(copy);
 
         return EXIT_OK;
 }
@@ -243,13 +233,13 @@ int getClip(char* CallerID)
 
         answer[0] = '\0';
 
-        logger("DEBUG", "getClip()");
+        logger("DBG", "getClip()");
 
 
         // Some phones uses AT+CLCC?, some just AT+CLCC (Sagem, Siemens-S55, SE-K750)
 
         if (useQuestionInCLCC == 0) {
-        	//logger("DEBUG", "getClip() send AT+CLCC");
+        	//logger("DBG", "getClip() send AT+CLCC");
 
                 strcpy(clcc,DEF_AT_CLCC);
                 strcat(clcc,"\r");
@@ -261,7 +251,7 @@ int getClip(char* CallerID)
                         return EXIT_EXACT;
                 } else if (strstr(answer,"OK") != NULL) {
                 	return EXIT_OK;
-                } else if (strstr(answer,"ERROR") != NULL) {
+                } else if (strstr(answer,"ERR") != NULL) {
                 	logger("WARNING", "Got ERROR on AT+CLCC. Will try AT+CLCC?");
                         useQuestionInCLCC = 1;      // Ask phone again; but will never ask AT+CLCC more
                 } else {
@@ -273,7 +263,7 @@ int getClip(char* CallerID)
         	
                 tryAnyway = 0;
 
-                //logger("DEBUG", "getClip() send AT+CLCC?");
+                //logger("DBG", "getClip() send AT+CLCC?");
 
                 strcpy(clcc,DEF_AT_CLCC);
                 strcat(clcc,"?");
@@ -286,8 +276,8 @@ int getClip(char* CallerID)
                         return EXIT_EXACT;
                 } else if (strstr(answer,"OK") != NULL) {
                 	return EXIT_OK;
-                } else if (strstr(answer,"ERROR") != NULL) {
-                	logger("ERROR", "Got ERROR on AT+CLCC?");
+                } else if (strstr(answer,"ERR") != NULL) {
+                	logger("ERR", "Got ERROR on AT+CLCC?");
                         return EXIT_NOK;
                 }
         }
