@@ -48,6 +48,8 @@
 #include <err.h>
 #endif
 
+#include <glib.h>
+
 #include "btio.h"
 #include "common.h"
 #include "parse.h"
@@ -55,6 +57,7 @@
 #include "conf.h"
 
 extern char tmp[MAXMAXLEN];
+extern gboolean stillRun;
 
 static int portfd       = 0;
 static int sportfd      = 0;
@@ -74,9 +77,9 @@ int bt_open_port(char* port)
 	
 	/* get a file descriptor */
 	if ((portfd = open(port, O_RDWR | O_NOCTTY | O_NDELAY)) < 0) {
-		sprintf(tmp, "can't open %s", port);
-		logger("ERROR", tmp);
-		printf("ERROR: can't open %s\n", port);
+		sprintf(tmp, "can not open %s", port);
+		logger("ERR", tmp);
+		printf("ERROR: can not open %s\n", port);
 		portfd = 0;
 		return -1;
 	}
@@ -89,7 +92,7 @@ int bt_open_port(char* port)
 
 	/* get port attributes, store in oldterm */
 	if (tcgetattr(portfd, &oldterm) < 0) {
-		printf("ERROR: Can't get port attributes (%s)\n", port);
+		printf("ERROR: Can not get port attributes (%s)\n", port);
 		return -1;
 	}
 
@@ -131,10 +134,9 @@ int bt_open_port(char* port)
 int bt_close_port(int final) 
 {
 	int retval = 0;
-	//printf("INFO: Close port\n");
 
 	if (!portfd) { /* already closed */
-		printf("INFO: Already closed ?\n");
+		logger("INF", "Already closed ?");
 		return -1;
 	}
 
@@ -180,7 +182,7 @@ int bt_read_tmo(char* buf, int len, int timeout)
 	if (ok > 0) {
 		ok = read(portfd, buf, len);
 		if (ok == 0) {
-			logger("DEBUG", "EOF during read()");
+			logger("DBG", "EOF during read()");
 			return EOF;
 		}
 	
@@ -189,7 +191,7 @@ int bt_read_tmo(char* buf, int len, int timeout)
 		//	char buf2[1024];
 		//	strncpy(buf2,buf,ok);
 		//	sprintf(tmp, "READ: %s", buf2);
-		//	logger("DEBUG", tmp);
+		//	logger("DBG", tmp);
 		//}
 		//////////////////////////////////////
 		return ok;
@@ -225,15 +227,6 @@ int  bt_readchar(char* c, int timeout)
 	return EOF;
 }
 
-int bt_write(char* buf, int len) 
-{
-	return write(portfd, buf, len);
-}
-
-int bt_getfd(void) {
-	return portfd;
-}
-
 // max should be >= 100
 int bt_put_command(char* command,
 		   char* answer,
@@ -246,10 +239,14 @@ int bt_put_command(char* command,
 	char tmp2[100];
 	int timeoutcounter=0;
 	int found=0;
+	
+	if (portfd < 0) {
+		return 0;
+	}
 
-	logger("DEBUG",command);
+	logger("DBG",command);
 	if (expect != NULL) {
-		logger("DEBUG",expect);
+		logger("DBG",expect);
 	}
 	
 	// send command
@@ -285,14 +282,14 @@ int bt_put_command(char* command,
 			if ((timeoutcounter<timeout) && (found==0)) {
 				
 				// check if it's the expected answer
-				if ((strstr(answer,"OK\r") || strstr(answer,"ERROR")) && expect == NULL) {
+				if ((strstr(answer,"OK\r") || strstr(answer,"ERR")) && expect == NULL) {
 					found=1;
 				}
 			
 				if (expect && expect[0]) {
 					if (strstr(answer,expect)) {
 						sprintf(tmp, "Got expected %s (iteration %d)", answer, timeoutcounter);
-						logger("DEBUG", tmp);
+						logger("DBG", tmp);
 						found=1;
 					}
 				}
@@ -314,7 +311,7 @@ int bt_put_command(char* command,
 		while (a2[0] == '\r' || a2[0] == '\n')  {
 			a2++;
 		}
-		logger("DEBUG",a2);
+		logger("DBG",a2);
 	}
 
 	return count;
@@ -414,15 +411,15 @@ int readStdin(char* buf, int max)
 int unix_open_port(char* port) 
 {
 	sprintf(tmp, "unix_open_port >%s<", port);
-	logger("INFO", tmp);
+	logger("INF", tmp);
 	
 	struct sockaddr_un serveraddr;
 
 	portfd = socket(AF_UNIX, SOCK_STREAM, 0);
 	if (portfd < 0) {
-		sprintf(tmp, "can't open UNIX %s", port);
-		logger("ERROR", tmp);
-		printf("ERROR: can't open UNIX %s\n", port);
+		sprintf(tmp, "can not open UNIX %s", port);
+		logger("ERR", tmp);
+		printf("ERROR: can not open UNIX %s\n", port);
 		portfd = 0;
 		return -1;
 	}
@@ -432,9 +429,9 @@ int unix_open_port(char* port)
 
 	int ret = connect(portfd, (struct sockaddr *)&serveraddr, SUN_LEN(&serveraddr));
 	if (ret < 0) {
-		sprintf(tmp, "can't open UNIX socket %s", port);
-		logger("ERROR", tmp);
-		printf("ERROR: can't open UNIX socket %s\n", port);
+		sprintf(tmp, "can not open UNIX socket %s", port);
+		logger("ERR", tmp);
+		printf("ERROR: can not open UNIX socket %s\n", port);
 		portfd = 0;
 		return -1;
 	}
@@ -469,11 +466,11 @@ int unix_read_port(char* buf, int l)
 		int rc = recv(portfd, & buf[bytesReceived], l - bytesReceived, 0);
 		printf("unix_read_port %d\n",rc);
 		if (rc < 0) {
-	   		//logger("ERROR","recv() failed");
+	   		//logger("ERR","recv() failed");
 			ret = EOF-1;
 	   		break;
 		} else if (rc == 0) {
-	   		//logger("INFO","Read 0 bytes");
+	   		//logger("INF","Read 0 bytes");
 			ret = EOF;
 	   		break;
 		}
@@ -556,13 +553,15 @@ void sdpRegister(int port)
     sdp_set_access_protos( record, access_proto_list );
 
     // set the name, provider, and description
-    sdp_set_info_attr(record, getServiceName(), service_prov, svc_dsc);
+    char *sn = getServiceName();
+    sdp_set_info_attr(record, sn, service_prov, svc_dsc);
+    free(sn);
 
     // connect to the local SDP server, register the service record, 
     // and disconnect
     session = sdp_connect(BDADDR_ANY, BDADDR_LOCAL, SDP_RETRY_IF_BUSY);
     if ( (!(session && record)) || sdp_record_register(session, record, 0) == -1) {
-        logger("ERROR", "can not register SDP service");
+        logger("ERR", "can not register SDP service");
     }
 
     // cleanup
@@ -610,8 +609,9 @@ void sdpRegister(int port)
 }
 #endif
 
-void sdpDeregister()
+static void sdpDeregister()
 {
+    logger("DBG", "Deregister SDP service");
     #ifdef USE_BLUEZ
     if (session != NULL) {
         sdp_record_unregister(session, record);
@@ -652,7 +652,7 @@ int openSocketPort(int type, int port, char *path)
 	int sz;
 
 	if (sportfd) { 
-		logger("ERROR", "socket was already opened");
+		logger("ERR", "socket was already opened");
 		//close(sportfd);
 		//sportfd = 0;
 		return 1;
@@ -674,12 +674,12 @@ int openSocketPort(int type, int port, char *path)
 		addFamily = AF_UNIX;
 		proto	  = 0;
 	} else {
-		logger("ERROR", "incorrect input");
+		logger("ERR", "incorrect input");
 		return -1;
 	}
 
 	if ((sportfd = socket(addFamily, SOCK_STREAM, proto)) < 0) {
-		logger("ERROR", "opening socket");
+		logger("ERR", "opening socket");
 		printf("ERROR: opening socket\n");
 	
 		return -1;
@@ -725,7 +725,7 @@ int openSocketPort(int type, int port, char *path)
 
                 sdpRegister(port);
 		sprintf(tmp, "registered SP for channel %i", port);
-		logger("INFO", tmp);
+		logger("INF", tmp);
 		socketaddr=(struct sockaddr *)&bt_addr;
 		#endif
 		
@@ -737,7 +737,7 @@ int openSocketPort(int type, int port, char *path)
 		bt_addr.rfcomm_channel =  (uint8_t) port;;
 		sdpRegister(port);
 		sprintf(tmp, "registered SP for channel %i", port);
-		logger("INFO", tmp);
+		logger("INF", tmp);
 		
 		socketaddr=(struct sockaddr *)&bt_addr;
 		sz = sizeof(bt_addr);
@@ -752,12 +752,12 @@ int openSocketPort(int type, int port, char *path)
 		sz = sizeof(un_addr);
 	
 	} else {
-		logger("ERROR", "incorrect input 2");
+		logger("ERR", "incorrect input 2");
 		return -1;
 	}
 
 	if (bind(sportfd, (struct sockaddr *) socketaddr, sz) < 0) {
-		logger("ERROR", "on binding");
+		logger("ERR", "on binding");
 		printf("ERROR: on binding %d->%s\n", errno, strerror(errno));
 		return -1;
 	}
@@ -768,9 +768,9 @@ int openSocketPort(int type, int port, char *path)
 	return 1;
 }
 
-int closeSocketPort(int type) 
+int closeSocketPort(int type, int final) 
 {
-	logger("INFO", "closeSocketPort");
+	logger("INF", "closeSocketPort");
 	
 	if (portfd) { 
 		close(portfd);
@@ -780,8 +780,10 @@ int closeSocketPort(int type)
 		close(sportfd);
 		sportfd = 0;
 	}
-
-	if (type == SERVER_UX) {
+	if (type == SERVER_BT && final){	
+		sdpDeregister();
+		freeBtAddress();
+	} else if (type == SERVER_UX) {
 		unlink(uSocket);
 		free(uSocket);
         }
@@ -805,7 +807,7 @@ int listenAndAcceptSocketConn(int type)
 	struct sockaddr_rfcomm bt_addr;
 	#endif
 
-	logger("INFO", "listenAndAcceptSocketConn");
+	logger("INF", "listenAndAcceptSocketConn");
 	cnt = 0;
 
 	if (type == SERVER_BT) {
@@ -818,7 +820,10 @@ int listenAndAcceptSocketConn(int type)
 		sz = sizeof(ip_addr);
 	}
 
-	while (1) {	       
+	while (stillRun) {
+	
+	        //logger("INF", "listenAndAcceptSocketConn: accept");
+			       
 		listen(sportfd,5);
 		 
 		portfd = accept(sportfd, (struct sockaddr *) socketaddr, (socklen_t *)&sz);
@@ -826,7 +831,7 @@ int listenAndAcceptSocketConn(int type)
 		if (portfd == -1 && errno == EAGAIN) {
 			
 			if (cnt >= 60) {    // Print to log every minute
-				logger("INFO", "listenAndAcceptSocketConn: waiting for connection");
+				logger("INF", "listenAndAcceptSocketConn: waiting for connection");
 				//printf(".");
 				cnt = 0;
 			}
@@ -839,7 +844,7 @@ int listenAndAcceptSocketConn(int type)
 		}	 
 		 
 		if (portfd < 0) {
-			logger("ERROR", "on accept");
+			logger("ERR", "on accept");
 			printf("ERROR: on accept %d\n", errno);
 			return -1;
 		/*} else {
@@ -850,7 +855,7 @@ int listenAndAcceptSocketConn(int type)
 			fcntl(portfd, F_SETFL, flags | O_NONBLOCK);
 		*/
 		}
-		logger("INFO", "listenAndAcceptSocketConn: accepted");
+		logger("INF", "listenAndAcceptSocketConn: accepted");
 	
 		#ifdef USE_BLUEZ
 		if (type == SERVER_BT) {
@@ -861,7 +866,7 @@ int listenAndAcceptSocketConn(int type)
 			btAddress = batostr(&ba);
 			
 			sprintf(tmp, "listenAndAcceptSocketConn: remote BT address is %s", btAddress);
-			logger("INFO", tmp);
+			logger("INF", tmp);
 		}
 		#endif
 		#ifdef USE_BT_FBSD
@@ -872,7 +877,7 @@ int listenAndAcceptSocketConn(int type)
 			btAddress = strdup(bt_ntoa(&bt_addr.rfcomm_bdaddr, NULL));
 			
 			sprintf(tmp, "listenAndAcceptSocketConn: remote BT address is %s", btAddress);
-			logger("INFO", tmp);
+			logger("INF", tmp);
 		}
 		#endif
 	
@@ -883,10 +888,10 @@ int listenAndAcceptSocketConn(int type)
 
 int writeSocketConn(char* command, int count)
 {
-	logger("DEBUG", "writeSocketConn");
+	logger("DBG", "writeSocketConn");
 
 	// send command
-	if (count > 0) {
+	if (portfd > 0 && count > 0) {
         
 		memset(tmp, 0, MAXMAXLEN);
         	strcat(tmp, "writeSocketConn ");
@@ -896,39 +901,42 @@ int writeSocketConn(char* command, int count)
                 // it is possible to get binary data here
                 memcpy(tmp, command, logSz); // Do not dump long commands
                 tmp[logSz] = '\0';
-        	logger("DEBUG", tmp);
+        	logger("DBG", tmp);
 		
 		sprintf(tmp, "writeSocketConn %d bytes", count);
-		logger("INFO", tmp);
+		logger("INF", tmp);
 
         	int n = write(portfd,command,count);        
         	if (n < 0) {
-        		logger("ERROR", "error writing to socket");
+        		logger("ERR", "error writing to socket");
         		return EXIT_NOK;
         	}
         	//tcdrain(portfd);
+		return EXIT_OK;
+	} else {
+		logger("ERR", "error writing to socket: already closed");
 	}
-	return EXIT_OK;
+	return EXIT_NOK;
 }
 
 int writeBytesSocketConn(char* command) 
 {
-	//logger("DEBUG", "writeBytesSocketConn");
+	//logger("DBG", "writeBytesSocketConn");
 
 	// send command
-	if (command && command[0]) {
+	if (portfd > 0 && command && command[0]) {
 		
 		char byteStr[MAXCKPDLEN];
 		strncpy(byteStr,command,MAXCKPDLEN-1);
 
 		sprintf(tmp, "writeBytesSocketConn >%s<", byteStr);
-		logger("DEBUG", tmp);
+		logger("DBG", tmp);
 
 		char* bStr = strtok(byteStr,",");
 		while (bStr != NULL) {
 			
 			//sprintf(tmp, "Next byte is >%s<", bStr);
-			//logger("DEBUG", tmp);
+			//logger("DBG", tmp);
 
 			char bStripped[4];
 		
@@ -944,20 +952,20 @@ int writeBytesSocketConn(char* command)
 			bStripped[i] = '\0';
 
 			sprintf(tmp, "Next byte is >%s<", bStripped);
-			logger("DEBUG", tmp);
+			logger("DBG", tmp);
 		
 			unsigned char byte2write[2];
 			byte2write[0] = (unsigned char) atoi(bStripped);
 			byte2write[1] = '\0';
 		
 			if ( write(portfd, byte2write, 1) < 0) {
-				logger("ERROR", "error writing to socket");
+				logger("ERR", "error writing to socket");
 				return EXIT_NOK;
 			}
 			bStr = strtok(NULL,",");
 		}
 	}
-	//logger("DEBUG", "writeBytesSocketConn EXIT");
+	//logger("DBG", "writeBytesSocketConn EXIT");
 	return EXIT_OK;
 }
 
