@@ -36,10 +36,12 @@
 #define SEND_STRING     "string"
 #define SEND_BYTES      "bytes"
 
-void        setToFile       (void);
-int  	    handleCmdByKey  (type_key* k, cmdParams *p);
-int 	    processCommands (cmdItem* cmdList, cmdParams *p);
-int         execDynamically (char *command);
-void        flushOldConf    (void);
+void	setToFile	(void);
+void 	handleCmdByKey  (type_key* k, cmdParams *p);
+void    handleCmdByKeyEx(type_key* k, cmdParams* p, int sendToMain);
+int 	processCommands (cmdItem* cmdList, cmdParams *p);
+int 	execDynamically (char *command);
+void	flushOldConf	(void);
+int	handleHook      (int hook);
 
 #endif
