@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#include <termios.h>
 
 #include "parse.h"
 #include "utils.h"
@@ -37,50 +38,176 @@ extern mode       *modes;
 extern mode       *currentMode;
 extern mode       *internalMode;
 extern mode 	  *defMode;
-extern type_alias *aliases;
-extern type_key   *alarms;
 extern CONF       conf;
 
+type_alarm *alarms = NULL;
+
 /* ----------------- Interface functions ------------------------- */
 
+// caller function must free data
+static char* dupVarValue(char *name, int size)
+{       
+        varData* v = searchVar(name, size);
+	if (v != NULL && v->value != NULL && v->value[0] != '\0') {
+		char *d = malloc(v->size+1);
+		strncpy(d,v->value,v->size);
+		d[v->size] = '\0';
+		return d;
+	}
+	return NULL;
+}
+
 int getLog()
-{
-	return (conf.log >  0 ? 1 : 0);
+{       
+        varData* v = searchVar("Logging", 7);
+        if (v != NULL && strncmp(v->value,"false",5) != 0) {
+		return 1;
+	}
+	return 0;
 }
 
 int getDebug()
 {
-	return (conf.log == 2 ? 1 : 0);
+        varData* v = searchVar("Logging", 7);
+        if (v != NULL && strncmp(v->value,"debug",5) == 0) {
+		return 1;
+	}
+	return 0;
 }
 
 char* getDevice()
 {
-	return conf.device;
+        return dupVarValue("Device", 6);
 }
 
 int getBaudrate()
 {
-	return conf.baudrate;
+	char br[16] = "";	// enough for 234000 
+        varData* v = searchVar("Baudrate", 12);
+        if (v != NULL) {
+	        strncpy(br,v->value,v->size);
+		
+		int rate = atoi(br);
+		
+		switch (rate) {
+			case 300:   return B300;
+			case 1200:  return B1200;
+			case 2400:  return B2400;
+			case 9600:  return B9600;
+			case 19200: return B19200;
+			case 38400: return 38400;
+			#ifdef B57600
+			case 57600: return B57600;
+			#endif
+			#ifdef B115200
+			case 115200: return B115200;
+			#endif
+			#ifdef B230400
+			case 230400: return B230400;
+			#endif
+			default:
+				WARNING2("bad baudrate %d, defaulting to 9600", rate);
+		 		return B9600;
+  		}
+	}
+	return B19200;
 }
 
 int getRetrySecs()
 {
-	return conf.retrysecs;
+	char rs[16] = "";	// should be enough 
+        varData* v = searchVar("RetrySeconds", 12);
+        if (v != NULL) {
+	        strncpy(rs,v->value,v->size);
+		return atoi(rs);
+	}
+	return 10;
 }
 
 int autoConnect()
 {
-	return conf.autoConnect;
+        varData* v = searchVar("AutoConnect", 11);
+        if (v != NULL && strncmp(v->value,"true",4) == 0) {
+		return 1;
+	}
+	return 0;
 }
 
 int getAutoRepeat()
 {
-	return conf.autoRepeat;
+        varData* v = searchVar("AutoRepeat", 10);
+        if (v != NULL && strncmp(v->value,"true",4) == 0) {
+		return 1;
+	}
+	return 0;
 }
 
 int getUseScreen()
 {
-	return conf.screen;
+        varData* v = searchVar("TwoWayComm", 10);
+        if (v != NULL && strncmp(v->value,"true",4) == 0) {
+		return 1;
+	}
+	return 0;
+}
+
+char* getCharset()
+{
+        return dupVarValue("CharSet", 7);
+}
+
+char* getToMainMenu()
+{
+        return dupVarValue("ToMainMenu", 10);
+}
+
+char* getServiceName()
+{
+        return dupVarValue("ServiceName", 11);
+}
+
+char* getAT_CMER(int what)
+{
+	if (what == CMER_ON) {
+	        char *cmer = dupVarValue("CmerOn", 6);
+
+		if  (cmer == NULL) {
+			if (conf.model == MODEL_MOTOROLA) {
+				return strdup(DEF_AT_CMER_ON_MOTOROLA);
+			} else if (conf.model == MODEL_SE) {
+				return strdup(DEF_AT_CMER_ON_SE);
+			} else if (conf.model == MODEL_SAGEM) {
+				return strdup(DEF_AT_CMER_ON_SAGEM);
+			} else if (conf.model == MODEL_SIEMENS) {
+				return strdup(DEF_AT_CMER_ON_SIEMENS);
+			} else {
+				return strdup(DEF_AT_CMER_ON_DEFAULT);
+			}
+		} else {
+			return cmer;
+		}
+	}
+
+	if (what == CMER_OFF) {
+		char *cmer = dupVarValue("CmerOff", 7);
+                
+		if  (cmer == NULL) {
+			if (conf.model == MODEL_MOTOROLA) {
+				return strdup(DEF_AT_CMER_OFF_MOTOROLA);
+			} else if (conf.model == MODEL_SE) {
+				return strdup(DEF_AT_CMER_OFF_SE);
+			} else if (conf.model == MODEL_SAGEM) {
+				return strdup(DEF_AT_CMER_OFF_SAGEM);
+			} else if (conf.model == MODEL_SIEMENS) {
+				return strdup(DEF_AT_CMER_OFF_SIEMENS);
+			} else {
+				return strdup(DEF_AT_CMER_OFF_DEFAULT);
+			}
+		} else {
+			return cmer;
+		}
+	}
+	return NULL;
 }
 
 int getFrontEnd()
@@ -93,65 +220,17 @@ int getHttp()
 	return conf.http;
 }
 
-char* getCharset()
+int usePassword()
 {
-	return (conf.charset[0] == '\0' ? NULL : conf.charset);
+	return conf.pass;
 }
 
+
 char* getCfgDir(void) 
 {
 	return conf.cfgDir;
 }
 
-char* getToMainMenu()
-{
-	return  (conf.toMain[0] == '\0' ? NULL : conf.toMain);
-}
-char* getServiceName()
-{
-	return conf.serviceName;
-}
-
-char* getAT_CMER(int what)
-{
-	if (what == CMER_ON) {
-		if  (conf.cmerOn[0] == '\0') {
-			if (conf.model == MODEL_MOTOROLA) {
-				return DEF_AT_CMER_ON_MOTOROLA;
-			} else if (conf.model == MODEL_SE) {
-				return DEF_AT_CMER_ON_SE;
-			} else if (conf.model == MODEL_SAGEM) {
-				return DEF_AT_CMER_ON_SAGEM;
-			} else if (conf.model == MODEL_SIEMENS) {
-				return DEF_AT_CMER_ON_SIEMENS;
-			} else {
-				return DEF_AT_CMER_ON_DEFAULT;
-			}
-		} else {
-			return conf.cmerOn;
-		}
-	}
-
-	if (what == CMER_OFF) {
-		if  (conf.cmerOff[0] == '\0') {
-			if (conf.model == MODEL_MOTOROLA) {
-				return DEF_AT_CMER_OFF_MOTOROLA;
-			} else if (conf.model == MODEL_SE) {
-				return DEF_AT_CMER_OFF_SE;
-			} else if (conf.model == MODEL_SAGEM) {
-				return DEF_AT_CMER_OFF_SAGEM;
-			} else if (conf.model == MODEL_SIEMENS) {
-				return DEF_AT_CMER_OFF_SIEMENS;
-			} else {
-				return DEF_AT_CMER_OFF_DEFAULT;
-			}
-		} else {
-			return conf.cmerOff;
-		}
-	}
-	return NULL;
-}
-
 char *getMode (void) 
 {
 	return (currentMode == NULL ? NULL : currentMode->name);
@@ -179,52 +258,56 @@ int getModel (void)
 	return conf.model;
 }
 
-char* getAlarmInfo(int which, cmdItem ** cmds)
+/////////////////////////////////////////////////////////////////////////////////////////////////
+
+void addAlarm(char *file, char *macro)
 {
-	int i;
-        type_key *tk = alarms;
+	sprintf(tmp,"addAlarm() >%s< >%s<\n", file,macro);
+	logger("DBG",tmp);
         
-	for (i=0;i<which;i++) {
-        	if (tk != NULL) {
-        		tk = tk->next;
-                } else {
-                	break;
-                }
+	type_alarm * v = (type_alarm *) calloc(sizeof(type_alarm),1);
+        v->file  = strdup(file);
+        v->macro = strdup(macro);
+	
+        // Insert in head
+        if (alarms == NULL) { 		// Insert first
+        	v->next = NULL;
+        } else {
+        	v->next = alarms;
         }
-        
-        if (i<which || tk == NULL) {
+        alarms = v;
+}
+
+static type_alarm *tk = NULL;
+
+char* getFirstAlarm(char** macro)
+{
+	if (alarms == NULL) {
+	        //logger("DBG","no any alarm found");
         	return NULL;
         }
-    	*cmds = tk->cmd;
-    
- 	return tk->key;
+	tk = alarms;
+    	
+	*macro = tk->macro;
+ 	return tk->file;
+}
+	
+char* getNextAlarm(char** macro)
+{
+        if (tk != NULL) {
+        	tk = tk->next;
+        }
+        
+        if (tk == NULL) {
+        	return NULL;
+        }
+    	
+	*macro = tk->macro;
+ 	return tk->file;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////
 
-char* findAlias(char *keyIn)
-{
-	type_alias* al = aliases;
-	char key[MAXARGLEN];
-
-	if (*keyIn == '\0') {
-		strcpy(key, EMPTY_STR);
-	} else {
-	 	strncpy(key, keyIn, MAXARGLEN - 1);
-	}
-
-	while (al) {
-		if (strcmp(key, al->key) == 0) {
-			sprintf(tmp,"found alias %s=%s", key, al->alias);
-			logger("DEBUG",tmp);   
-	
-			return al->alias;
-		}
-		al = al->next;
-	}
-	return NULL;
-}
-
 static type_key* findStartingWith(mode *mode, char *key)
 {
         if (mode == NULL) {
@@ -237,7 +320,7 @@ static type_key* findStartingWith(mode *mode, char *key)
 
 		if (start && start == It->key) {    // We got a part of multi-key or parametrized command
 			
-			logger("DEBUG","Found part of multi-key or parametrized command");
+			logger("DBG","Found part of multi-key or parametrized command");
 			return It;
 		} 
 		It = (type_key*) It->next;
@@ -249,20 +332,25 @@ static type_key* findStartingWith(mode *mode, char *key)
 static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *params) 
 {
 	if (mode == NULL) {
-		logger("DEBUG","findItemInMode: mode is null");
+		logger("DBG","findItemInMode: mode is null");
 		return NULL;
 	}
-
-	sprintf(tmp,"findItemInMode >%s,%s<", mode->name, key);
-	logger("DEBUG",tmp);
-
+	int canLog = (strcmp(mode->name,"_INTERNAL_") != 0);
+	
+	if(canLog) {
+		sprintf(tmp,"findItemInMode >%s,%s<", mode->name, key);
+		logger("DBG",tmp);
+	}
+	
 	// Prepare to search as parametrized command, control presence of both ( and )
 	char *start  = index(key,'(');
 	char *finish = rindex(key,')');
 
 	if ((start != NULL && finish == NULL) ||  // Command was read partially?
             (start == NULL && finish != NULL)) {  // Command was incorectrly formed ?
-		logger("DEBUG","findItemInMode: Incorrectly formed parametrized command. One brace is absent");
+		if(canLog) {
+			logger("DBG","findItemInMode: Incorrectly formed parametrized command. One brace is absent");
+		}
 		return NULL;
 	}
         
@@ -274,20 +362,22 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 
 	type_key* It = findExact(mode,key);	// Search exact command
 	if (It) {
-		//logger("DEBUG","Found exact command");
+		//logger("DBG","Found exact command");
 		*flag = FLAG_EXACT;
 		return It;
 	} 
 
 	It = findStartingWith(mode,key);	// Search as part of multikey sequence
 	if (It) {
-		//logger("DEBUG","Found part of multi-key command");
+		//logger("DBG","Found part of multi-key command");
 		*flag = FLAG_MULTIKEY;
 		return It;
 	} 
 
 	if (params == NULL) {
-		logger("DEBUG","findItemInMode: No parameters suspected. Item does not found.");
+		if(canLog) {
+			logger("DBG","findItemInMode: No parameters suspected. Item does not found.");
+		}
 		return NULL;
 	}
 
@@ -297,7 +387,7 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 		It = mode->keys;
 	
 		char tag  [MAXARGLEN];
-		char index[4];
+		char index[6];
 		char value[MAXARGLEN];
 	
 		strncpy(tag, key, start-key);
@@ -305,12 +395,16 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 	
 		char *comma = strstr(start+1,",");
 		if (comma == NULL || comma > finish) { // Parametrized command from Java Client should be in a form like List(1,String1)
-			logger("DEBUG","findItemInMode: Incorrectly formed parametrized command");
+			if(canLog) {
+				logger("DBG","findItemInMode: Incorrectly formed parametrized command");
+			}
 			return NULL;
 		}
 
-		if (comma-start > 5) {
-			logger("ERROR","findItemInMode: Received incorrect index!");
+		if (comma-start > 6) { // 65535 = max value in Comman Fusion iViewer
+			if(canLog) {
+				logger("ERR","findItemInMode: Received incorrect index!");
+			}
 			return NULL;
 		}
 		strncpy(index,start+1,comma-start-1);
@@ -319,9 +413,11 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 		strncpy(value,comma+1,finish-comma-1);
 		*(value+(finish-comma-1)) = '\0';
 
-		sprintf(tmp,"Parametrized command parsed as >%s< >%s< >%s< ", tag,index,value);
-		logger("DEBUG",tmp);
-	
+		if(canLog) {
+			sprintf(tmp,"Parametrized command parsed as >%s< >%s< >%s< ", tag,index,value);
+			logger("DBG",tmp);
+		}
+		
 		// Try to search explicitly specified parametrized command (for ex List(1) or List(commandX))
 		// By index
 		strcat(tag,"(");
@@ -330,7 +426,9 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 		It = findExact(mode,tag);
 
 		if (It) {
-			logger("DEBUG","Found exact (explicitly specified by index) parametrized command");
+			if(canLog) {
+				logger("DBG","Found exact (explicitly specified by index) parametrized command");
+			}
 			*flag = FLAG_EXACT;
 			return It;
 		} 
@@ -342,7 +440,9 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 		It = findExact(mode,tag);
 
 		if (It) {
-			logger("DEBUG","Found exact (explicitly specified by value) parametrized command");
+			if(canLog) {
+				logger("DBG","Found exact (explicitly specified by value) parametrized command");
+			}
 			*flag = FLAG_EXACT;
 			return It;
 		} 
@@ -350,21 +450,19 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 		// Finally... Search command like ListItem($$)
 		*(tag+(start-key)) = '\0';
 		
-		char* keyAndBrace = calloc(1,strlen(tag)+2);
+		char* keyAndBrace = calloc(1,strlen(tag)+3);
 		strcpy(keyAndBrace,tag);
-		strcat(keyAndBrace,"(");
+		strcat(keyAndBrace,"($");
 		
-                //sprintf(tmp,"Search findStartingWith() >%s< ", keyAndBrace);
-                //logger("DEBUG",tmp);
-                DEBUG2("Search findStartingWith() >%s< ", keyAndBrace);
-                
+                if(canLog) {
+			DEBUG2("Search findStartingWith() >%s< ", keyAndBrace);
+                }
 		It = findStartingWith(mode,keyAndBrace);
 		free(keyAndBrace);
 		if (It) {
-	                //sprintf(tmp,"Found parametrized command >%s,%s< ", index,value);
-               		//logger("DEBUG",tmp);
-	                DEBUG2("Found parametrized command >%s,%s< ", index,value);
-
+			if(canLog) {
+	                	DEBUG2("Found parametrized command >%s,%s< ", index,value);
+			}
 			strcpy(params->index, index);
 			strcpy(params->value, value);
 	
@@ -372,14 +470,15 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 			return It;
 		} 
 	}
-
-	logger("DEBUG","findItemInMode: Item does not found");
+	if(canLog) {
+		logger("DBG","findItemInMode: Item does not found");
+	}
 	return NULL;
 }
 
 type_key* findItem(char *keyIn, int *flag, cmdParams *params) 
 {
-	//logger("DEBUG","findItem()"); 
+	//logger("DBG","findItem()"); 
 	type_key *tk = NULL;
 
 	if (keyIn == NULL) {
@@ -389,7 +488,7 @@ type_key* findItem(char *keyIn, int *flag, cmdParams *params)
 	char key[MAXARGLEN];
 
 	if (*keyIn == '\0') {
-		logger("INFO","Got empty key");   
+		logger("INF","Got empty key");   
 		strcpy(key, EMPTY_STR);
 	} else {
 		strncpy(key, keyIn, MAXARGLEN - 1);
@@ -398,21 +497,20 @@ type_key* findItem(char *keyIn, int *flag, cmdParams *params)
 	if (currentMode != NULL) {
 		tk = findItemInMode(currentMode, key, flag, params);
 		if (tk == NULL && currentMode != defMode) {
-			logger("DEBUG","findItem() search in default");
+			logger("DBG","findItem() search in default");
 			tk = findItemInMode(defMode, key, flag, params);
 		}
 	}
 	
 	//  Search in "internal" commands
 	if (tk == NULL) {
-	        logger("DEBUG","findItem() internal mode");
+	        logger("DBG","findItem() internal mode");
 		tk = findItemInMode(internalMode, key, flag, params);
 		if (tk != NULL && *flag == FLAG_MULTIKEY) {
-			logger("DEBUG","findItem() multikey in internal command ?");
+			logger("DBG","findItem() multikey in internal command ?");
 		}
 	}
 	
-	//logger("DEBUG","findItem() EXIT");
         /*if (tk && tk->cmd) {
         	printf("TRACE %s->%s:%s \n",keyIn,tk->cmd->descr,(tk->cmd->exec ? tk->cmd->exec : "NULL"));
         } else {
@@ -424,16 +522,16 @@ type_key* findItem(char *keyIn, int *flag, cmdParams *params)
 cmdItem *getCommand(type_key* item)
 {
 	if (!item) {
-		logger("DEBUG","getCommand(): Empty type_key was got");
+		logger("DBG","getCommand(): Empty type_key was got");
 		return NULL;
 	}
 	if (item->key == NULL) {
-		logger("DEBUG","Empty key was got");
+		logger("DBG","Empty key was got");
 		return NULL;
 	}
 
 	sprintf(tmp,"getCommand for >%s<", item->key);
-	logger("DEBUG",tmp);   
+	logger("DBG",tmp);   
 
 	return item->cmd;
 }
@@ -523,95 +621,14 @@ void printKeys()
 	return;
 }
 
-void printAlarms()
-{
-        logger("CFG", ALARMS_SECTION_STR);
-
-	printKeysInMode(alarms);
-
-        logger("CFG", SECTION_END_STR);
-	return;
-}
-
-void printAliases()
-{
-	type_alias *al = aliases;
-
-	logger("CFG", ALIAS_SECTION_STR);
-
-	while(al) {
-		sprintf(tmp, "\tKey %s \taliased to %s", al->key, al->alias);
-		logger("CFG", tmp);
-
-		al = al->next;
-	}
-	logger("CFG", SECTION_END_STR);
-
-	return;
-}
-
-void printParams()
-{
-	int atMode = 1;
-	if (strstr(conf.device, INET_SOCKET) != NULL || 
-	    strstr(conf.device, BT_SOCKET)   != NULL
-	    #ifdef USE_L2CAP
-	    || strstr(conf.device, L2CAP_SOCKET) != NULL
-	    #endif
-	    ) {
-		atMode = 0;
-	}
-
-	logger("CFG", "[Parameters]");
-	if (atMode) {
-		sprintf(tmp, "\tAutoConnect   %s", (conf.autoConnect?"Yes":"No"));
-		logger("CFG", tmp);
-	}
-	sprintf(tmp, "\tAutoRepeat    %s", (conf.autoRepeat?"Yes":"No"));
-	logger("CFG", tmp);
-	if (atMode) {
-		if (conf.cmerOn[0] != '\0') {
-			sprintf(tmp, "\tCMER On       %s", conf.cmerOn);
-			logger("CFG", tmp);
-		} else {
-			logger("CFG", "\tCMER On	   Will be determined automatically");
-		}
-		if (conf.cmerOff[0] != '\0') {
-			sprintf(tmp, "\tCMER Off      %s", conf.cmerOff);
-			logger("CFG", tmp);
-		} else {
-			logger("CFG", "\tCMER Off	   Will be determined automatically");  
-		}
-	}
-	sprintf(tmp, "\tDevice        %s", conf.device);
-	logger("CFG", tmp);
-	sprintf(tmp, "\tLog	      %s", (conf.log == 2?"Debug":(conf.log == 1?"Yes":"No")));
-	logger("CFG", tmp);
-	sprintf(tmp, "\tRetry Sec     %d", conf.retrysecs);
-	logger("CFG", tmp);
-	sprintf(tmp, "\tScreen Menu   %s", (conf.screen?"Yes":"No"));
-	logger("CFG", tmp);
-	if (atMode) {
-		sprintf(tmp, "\tTo Main Menu  %s", conf.toMain);
-		logger("CFG", tmp);
-	}
-	if (conf.frontEnd >= 0) {
-		sprintf(tmp, "\tWorks as back end");
-		sprintf(tmp, "\tPort          %d", conf.frontEnd);
-		logger("CFG", tmp);
-	}
-	logger("CFG", SECTION_END_STR);
-} 
-
 void printConf() 
 {
+	//printf("printConf ENTER\n");fflush(stdout);
 	printTime();
         sprintf(tmp, "anyRemote v%s", PACKAGE_VERSION);
         logger("CFG", tmp);
 	printKeys   ();
-	printAliases();
-	printAlarms ();
-	printParams ();
+	printVars   ();
 
 	return ;
 }
@@ -644,9 +661,9 @@ void freeCmds(cmdItem* item)
 	return;
 }
 
-void freeCfgEx(mode* pmodes, type_key* palarms, type_alias *paliases)
+void freeCfgEx(mode* pmodes, type_alarm* palarms)
 {
-	//logger("DEBUG", "freeCfgEx()");
+	//logger("DBG", "freeCfgEx()");
 	
 	// Keys
 	while(pmodes) {
@@ -669,31 +686,19 @@ void freeCfgEx(mode* pmodes, type_key* palarms, type_alias *paliases)
 	}
 	        
 	// Alarms
-        type_key *mk = palarms;
+        type_alarm *mk = palarms;
 	while (mk) {
-		type_key* It = mk;
-		mk = (type_key*) mk->next;
-		
-                freeCmds(It->cmd);
-
-		It->cmd = NULL;
-                free(It->key);
+		type_alarm* It = mk;
+		mk = (type_alarm*) mk->next;
+                free(It->file);
+                free(It->macro);
 		free(It);
 	}
-
-	// Aliases
-	while(paliases) {
-		type_alias *al = paliases->next;
-		free(paliases->key);
-		free(paliases->alias);		
-		free(paliases); paliases = NULL;
-		paliases = al;
-	}
 }
 
 void freeCfg(void)
 {
-	freeCfgEx(modes, alarms, aliases);
+	freeCfgEx(modes, alarms);
         
         // special handling for "internal" mode
         if (internalMode != NULL) {
