@@ -20,10 +20,12 @@
 //
 
 #ifndef _CONF_H_
-#define _CONF_H_ 1
+#define _CONF_H_
 
-char* findAlias         (char *keyIn);
-char* getAlarmInfo      (int which, cmdItem **cmds);
+#include "parse.h"
+
+char* getFirstAlarm     (char **cmds);
+char* getNextAlarm      (char **cmds);
 char* getAT_CMER     	(int what);
 char* getCfgDir         (void);
 char* getCharset        (void);
@@ -42,8 +44,9 @@ int   getRetrySecs  	(void);
 int   getUseScreen      (void);
 int   getHttp           (void);
 int   usePassword       (void);
+void  addAlarm		(char *file, char *macro);
 void  freeCfg           (void);
-void  freeCfgEx         (mode* pmodes, type_key* palarms, type_alias *paliases);
+void  freeCfgEx         (mode* pmodes, type_alarm* palarms);
 void  freeCmds          (cmdItem* item);
 void  printConf         (void);
 void  printKeys		(void);
