@@ -23,33 +23,20 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include <termios.h>
 #include <sys/stat.h>
 
 #include "parse.h"
 #include "utils.h"
 
-#define AUTOCONN_STR   	"AutoConnect"
-#define AUTOREPEAT_STR	"AutoRepeat"
-#define BAUD_STR    	"Baudrate"
-#define CHARSET_STR    	"CharSet"
-#define CMER_OFF_STR   	"CmerOff"
-#define CMER_ON_STR   	"CmerOn"
-#define DEVICE_STR   	"Device"
-#define LOG_STR    	"Log"
-#define RETRY_STR    	"RetrySecs"
-#define SCREEN_STR      "Screen"
-#define TOMAIN_STR   	"ToMainMenu"
-
 #include <regex.h>
 
 #define REGEX_KEYVAL   "^[[:space:]]*(\\[[[:alpha:]]+\\])([^=]*)$|^[[:space:]]*([^=%]*[^[:space:]]{1})[[:space:]]*=[[:space:]]*(.*[^[:space:]]{1})[[:space:]]*$"
-#define REGEX_CMDBYCMD "[[:space:]]*(Exec|ExecAndSet|Make|Get|Set|Send|ExecAndSend|Timer|Macro|Load|Include|SendCKPD|Emulate)[[:space:]]*(\\()|[[:space:]]*(Exit)[[:space:]]*;{0,1}"
+#define REGEX_CMDBYCMD "[[:space:]]*(Exec|ExecAndSet|Make|Get|Set|Send|ExecAndSend|Timer|Macro|Load|Include|SendCKPD|Emulate|Dbus)[[:space:]]*(\\()|[[:space:]]*(Exit)[[:space:]]*;{0,1}"
 
 #define REGEX_SET    "[[:space:]]*(bg|editfield|filemanager|fg|font|fullscreen|icons|list|iconlist|menu|parameter|skin|status|text|title|volume|image|cover|var)[[:space:]]*,[[:space:]]*(.*)|[[:space:]]*(vibrate|repaint|disconnect)[[:space:]]*"
 #define REGEX_GET    "[[:space:]]*(screen_size|cover_size|model|version|cursor|ping|password)[[:space:]]*|[[:space:]]*(is_exists)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*"
 #define REGEX_TIMER  "[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*$|[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*(cancel|pause|reset|restart|continue)"
-#define REGEX_MAKE   "[[:space:]]*(remote|mode|var)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*|[[:space:]]*(exit|flush|stop|disconnect|none)[[:space:]]*"
+#define REGEX_MAKE   "[[:space:]]*(remote|mode|var|alarm)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*|[[:space:]]*(exit|flush|stop|disconnect|none)[[:space:]]*"
 
 #define REGEX_SET_TL "[[:space:]]*(fg|bg|font|select)[[:space:]]*,(.*)|[[:space:]]*(add|replace)[[:space:]]*,[[:space:]]*([^[:space:]]{1}[^,]*[^[:space:]]{1})[[:space:]]*,[[:space:]]*(.*)|[[:space:]]*(close)[[:space:]]*,[[:space:]]*(clear)[[:space:]]*|[[:space:]]*(clear|close|show)[[:space:]]*"
 #define REGEX_SET_MN "[[:space:]]*(add|replace)[[:space:]]*,(.*)|[[:space:]]*(clear)[[:space:]]*"
@@ -70,35 +57,21 @@ mode       *modes        = NULL;
 mode       *currentMode  = NULL;
 mode       *internalMode = NULL;
 mode 	   *defMode      = NULL;
-type_alias *aliases      = NULL;
-type_key   *alarms       = NULL;
 
-CONF conf = { 0, 		// Log
-              B19200, 		// Baudrate
-              60, 		// Retrysecs
-              0, 		// use screen
-              0, 		// auto connect
-              0,		// auto repeat
-              "8859-1",         // charset
-              DEFAULT_DEVICE,   // device
-	      "",               // to main menu
-    	      "",               // CMER ON
-	      "",               // CMER OFF
-	      MODEL_DEFAULT,	// Model
+CONF conf = { MODEL_DEFAULT,	// Model
 	      NULL,             // Cfg. dir
 	      -1,		// Front-end port    
 	      0,		// Work with anyremote2html
 	      0,		// Ask password ?
-	      "anyRemote",      // Service name
 	      0,		// set uid
 	      0};        	// set gid
 
 type_key* findExact(mode *mode, char *key)
 {
-	//logger("DEBUG", "findExact()");
+	//logger("DBG", "findExact()");
         
         if (mode == NULL || key == NULL) {
-        	logger("DEBUG", "findExact() input is empty ?");
+        	logger("DBG", "findExact() input is empty ?");
         	return NULL;
         }
 	type_key* It = mode->keys;
@@ -106,12 +79,12 @@ type_key* findExact(mode *mode, char *key)
 	// Search exact command
 	while (It != NULL && It->key != NULL && strcmp(It->key,key) != 0) {
 		//sprintf(tmp,"findExact search >%s< compare to >%s<", It->key, key);
-		//logger("DEBUG",tmp);   
+		//logger("DBG",tmp);   
 
 		It = (type_key*) It->next;
-        	//logger("DEBUG", "findExact() next loop");
+        	//logger("DBG", "findExact() next loop");
 	}
-        //logger("DEBUG", "findExact() exiting");
+        //logger("DBG", "findExact() exiting");
 	return It;
 }
 
@@ -130,7 +103,7 @@ static mode* findMode(const char *name)
 void setMode (const char *modeName) 
 {
 	if (modeName ==  NULL) {
-               logger("DEBUG", "setMode() NULL input");
+               logger("DBG", "setMode() NULL input");
                return;
 	}
 	DEBUG2("setMode() to %s", modeName);
@@ -141,7 +114,7 @@ void setMode (const char *modeName)
 		currentMode = mp;
 		DEBUG2("setMode() new mode was set to %s", currentMode->name);
 	} else {
-		logger("DEBUG", "setMode() new mode did not found");
+		logger("DBG", "setMode() new mode did not found");
 	}
 
 	return;
@@ -175,7 +148,7 @@ static void setCfgDir(char *d)
 			conf.cfgDir = strdup(try2);
 			
 			free(try2);
-			//printf("CFG DIR >%s<\n",(conf.cfgDir?conf.cfgDir:"NULL"));
+			printf("CFG DIR >%s<\n",(conf.cfgDir?conf.cfgDir:"NULL"));
 			return;
 		}
 		free(try2);
@@ -194,67 +167,26 @@ static void setCfgDir(char *d)
 	//printf("CFG DIR >%s<\n",(conf.cfgDir?conf.cfgDir:"NULL"));
 }
 
-/* ----------------- Setup configuration functions ------------------------- */
-
-static int setBaudrate(int rate) 
-{
-  switch (rate) {
-	case 300:
-		return B300;
-	case 1200:
-		return B1200;
-	case 2400:
-		return B2400;
-	case 9600:
-		return B9600;
-	case 19200:
-        	return B19200;
-	case 38400:
-        	return 38400;
-	#ifdef B57600
-	case 57600:
-		return B57600;
-	#endif
-	#ifdef B115200
-	case 115200:
-		return B115200;
-	#endif
-	#ifdef B230400
-	case 230400:
-		return B230400;
-	#endif
-	default:
-		printf("WARNING: bad baudrate %d, defaulting to 9600\n", rate);
-  }
-
-  return B9600;
-}
-
 /* Parses command line options and set flags. */
 int parse_opts(int argc, char *argv[])
 {
 	int i;
 	for(i=1; i<argc; i++) {
 		if (strcmp(argv[i],"-log")==0 || strcmp(argv[i],"-l")==0) {
-			conf.log=2;
-		} else if (strcmp(argv[i],"-fe")==0 && i+1<argc) {
-			conf.frontEnd=atoi(argv[++i]);
+			setVarSimple("Logging", "debug");
+		} else if (strcmp(argv[i],"--autoconnect")==0 || strcmp(argv[i],"-a")==0) {
+			setVarSimple(AUTOCONN_STR, "true");
 		} else if ((strcmp(argv[i],"--serial")==0 || strcmp(argv[i],"-s")==0) && i+1<argc) {
-			strcpy(conf.device, argv[++i]);
-		} else if ((strcmp(argv[i],"--baud")==0 || strcmp(argv[i],"-b")==0) && i+1<argc) {
-			conf.baudrate = setBaudrate(atoi(argv[++i]));
-		} else if (strcmp(argv[i],"--noscreen")==0 || strcmp(argv[i],"-n")==0) {
-			conf.screen = 0;
+                        setVarSimple("Device", argv[++i]);
+		} else if (strcmp(argv[i],"-name")==0) {
+                        setVarSimple("ServiceName", argv[++i]);
+                } else if (strcmp(argv[i],"-fe")==0 && i+1<argc) {
+			conf.frontEnd=atoi(argv[++i]);
 		} else if (strcmp(argv[i],"-http")==0) {
 			conf.http = 1;
-		} else if (strcmp(argv[i],"--autoconnect")==0 || strcmp(argv[i],"-a")==0) {
-			conf.autoConnect = 1;
 		} else if (strcmp(argv[i],"--user")==0 || strcmp(argv[i],"-u")==0) {
 			if(getUidGid(argv[++i], &conf.uid, &conf.gid)!=EXIT_OK)
 				printf("WARNING: bad username %s\n", argv[i]);
-		} else if (strcmp(argv[i],"-name")==0) {
-                        strncpy(conf.serviceName, argv[++i],MTEXTLEN-1);
-			conf.serviceName[MTEXTLEN-1] = '\0';
 		} else if (strcmp(argv[i],"-password")==0) {
                         conf.pass = 1;
 		} else if (strcmp(argv[i],"-f")==0) {
@@ -443,6 +375,7 @@ char* id2Cmd (int cmdId)
 		case ID_GET:		    return CMD_GET;
 		case ID_MAKE:		    return CMD_MAKE;
 		case ID_EMU:		    return CMD_EMU;
+		case ID_DBUS:		    return CMD_DBUS;
 	
 		default:		    return "Unknown";
 	}
@@ -479,6 +412,8 @@ static int cmd2id (char *name)
 		return ID_MAKE;
         } else if (strcmp(name,CMD_EMU) == 0) {
 		return ID_EMU;
+        } else if (strcmp(name,CMD_DBUS) == 0) {
+		return ID_DBUS;
         } 
         return ID_UNKNOWN;
 }
@@ -510,78 +445,6 @@ int cmdSet2id (const char *name)
         return ID_UNKNOWN;
 }
 
-static void addAlias(char*old, char *new)
-{
-	type_alias* Al = (type_alias*) calloc(1, sizeof(type_alias));
-
-	// Insert in head
-	if (aliases == NULL) {   // first elem
-		Al->next = NULL;
-	} else {
-		Al->next = (type_alias*) aliases;
-	}
-	aliases = Al;
-	
-	Al->key   = (char *) malloc(strlen(old)+1);
-	Al->alias = (char *) malloc(strlen(new)+1);
-
-	strcpy(Al->key,  old);
-	strcpy(Al->alias,new);
-}
-
-/* preparation for i18n
-static char* translateWord (const char *word) 
-{
-	char *trWord = (char *) malloc(strlen(word)*2+1);
-	strcpy(trWord,word);
-	strcat(trWord,word);
-	return trWord;
-}
-
-static char* translateMenu (const char *menuString) 
-{
-	//printf("trMenu %d %s\n", strlen(menuString),menuString);
-	char *bufPtr;
-	char *menuString2 = strdup(menuString);
-
-        char *token = strtok_r(menuString2,",",&bufPtr);
-	char *trString = NULL;
-	int  init = 1;
-	while (token != NULL) {
-		// translate token
-		//printf("trMenu token = %s\n", token);fflush(stdout);
-		char * trToken = translateWord(token);
-		//printf("trMenu tr token = %s\n", trToken);fflush(stdout);
-                
-		addAlias(token,trToken);
-		
-		//printf("trMenu realloc %d->%d\n", 
-		//           (trString == NULL ? 0 : strlen(trString)), 
-		//	   (trString == NULL ? 0 : strlen(trString))+strlen(trToken)+2);fflush(stdout);
-
-		trString = (char *) realloc(trString,(trString == NULL ? 0 : strlen(trString))+strlen(trToken)+2);
-		if (init) {
-			*trString = '\0';
-			strcpy(trString,trToken);
-			init = 0;
-		} else {
-			strcat(trString,trToken);
-		}	
-		
-		free(trToken);
-		token = strtok_r(NULL,",",&bufPtr);
-		
-		if (token != NULL) {
-			strcat(trString,",");
-		}
-	}
-	
-	free(menuString2);
-	//printf("trMenu %d %s\n",strlen(trString),trString);fflush(stdout);
-	return trString;
-}
-*/
-
 static int storeGetCmd(cmdItem* ci, char *cmd)
 {
 	int parseFail = 0;
@@ -688,8 +551,8 @@ static int storeMakeCmd(cmdItem* ci, char *cmd)
                          	regfree(regex2);free(regex2);regex2 = NULL;
                                 free(result2);result2 = NULL;
 
-                        } else if (strncmp(cmd + result[1].rm_so, MAKE_MODE,    l) == 0) {	// mode
-                        
+                        } else if (strncmp(cmd + result[1].rm_so, MAKE_MODE,  l) == 0 ||	// mode
+                                   strncmp(cmd + result[1].rm_so, MAKE_ALARM, l) == 0) {	// alarm
                         	ci->descr = (char*) calloc(1, result[1].rm_eo - result[1].rm_so + 1);
                                 ci->exec  = (char*) calloc(1, result[2].rm_eo - result[2].rm_so + 1);
                                 strncpy(ci->descr,cmd + result[1].rm_so, result[1].rm_eo - result[1].rm_so); 
@@ -1481,67 +1344,6 @@ static void loadInternal()
 	char cmd2[] = "_PING_";
 	char val2[] = "Get(ping)";
 	storeKey(internalMode, &(internalMode->keys),cmd2,val2);
-	
-	/*
-	char cmd3[] = "_PASSWORD_INVALID_";
-	char val3[] = "Set(disconnect);Make(disconnect);Make(stop);";
-	storeKey(internalMode, &(internalMode->keys),cmd3,val3);*/
-}
-
-static int loadAliases(FILE *fp)
-{
-        char *tmptext;
-	char *key, *alias;
-	    
-
-	do {
-		tmptext=loadLine(fp);
-                
-		if (tmptext == NULL) return EXIT_NOK;
-	
-		key   = NULL;
-		alias = NULL;
-		parseKeyValue(tmptext, &key, &alias);
-	
-		if (key == NULL) { 
-			//printf("ERROR : incorrect alias %s\n", tmptext);
-			continue;
-		} else if(strcmp(key,SECTION_END_STR) == 0) {
-			break;
-		} else if (alias != NULL) {	// Line with key=alias definition
-			addAlias(key,alias);
-		} else {
-			continue;
-		}
-	} while (1);
-
-	return EXIT_OK;    
-}
-
-static int loadAlarms(FILE *fp)
-{
-        char *tmptext;
-	char *tag, *value;    
-
-	do {
-		tmptext=loadLine(fp);
-		
-                if (tmptext == NULL) return EXIT_NOK;
-	
-		parseKeyValue(tmptext, &tag, &value);
-	
-		if (tag == NULL) { 
-			continue;
-		} else if(strcmp(tag,SECTION_END_STR) == 0) {
-			break;
-		} else if (value != NULL) {// Line with key->command definition
-			storeKey(NULL, &alarms, tag, value);
-		} else {
-			continue;
-		}
-	} while (1);
-
-	return EXIT_OK;    
 }
 
 int load_cfg(char *mfile, int isInit)
@@ -1575,74 +1377,24 @@ int load_cfg(char *mfile, int isInit)
 		parseKeyValue(tmptext, &tag, &value);
 			
 		if (tag == NULL) { 
-			//printf("INFO : skip line %s\n", tmptext);
 			continue;
-		} else if (strcmp(tag,RETRY_STR) == 0 && isInit) {
-			if (value != NULL) {
-				conf.retrysecs=atoi(value);
-			}	    
-		} else if (strcmp(tag,DEVICE_STR) == 0 && isInit) {
-			if (value != NULL) {
-				strcpy(conf.device,value);
-			}	    
-		} else if (strcmp(tag,AUTOCONN_STR) == 0 && isInit) {
-			if (value != NULL && strncmp("true",value,4)==0) {
-			 	conf.autoConnect=1;
-			}	    
-		} else if (strcmp(tag,CHARSET_STR) == 0 && isInit) {
-		    if (value != NULL) {
-		    	strcpy(conf.charset,value);
-		    }		
-		} else if (strcmp(tag,LOG_STR) == 0 && isInit) {
-			if (value != NULL) {
-                        	if (strncmp("true",value,4)==0) {
-					conf.log=1;
-                                } else if (strncmp("debug",value,5)==0) {
-                                	conf.log=2;
-                                }
-			}	    
-		} else if (strcmp(tag,SCREEN_STR) == 0 && isInit) {
-			if (value != NULL && strncmp("true",value,4)==0) {
-				conf.screen=1;
-			}	    
-		} else if (strcmp(tag,BAUD_STR) == 0 && isInit) {
-			if (value != NULL) {
-				conf.baudrate = setBaudrate(atoi(value));
-			}	    
 		} else if (strcmp(tag,KEYS_SECTION_STR) == 0) {
+		        printf("WARNING: [Keys] tag is deprecated. Please update configuration files !\n");
 			if (loadKeys(fp) != EXIT_OK) {
 				return EXIT_NOK;
 			} 
                         if (!isInit) {		// If we goes here from Include() command, we did all we need
                         	return EXIT_OK;
                         }
-		} else if (strcmp(tag,ALIAS_SECTION_STR) == 0) {
-			if (loadAliases(fp) != EXIT_OK) {
-				return EXIT_NOK;
-			}
-		} else if (strcmp(tag,ALARMS_SECTION_STR) == 0) {
-			if (loadAlarms(fp) != EXIT_OK) {
+		} else if (strcmp(tag,PROTOCOL_SECTION_STR) == 0) {
+			if (loadKeys(fp) != EXIT_OK) {
 				return EXIT_NOK;
 			} 
-		} else if (strcmp(tag,TOMAIN_STR) == 0 && isInit) {
-			if(value!= NULL) {
-				strcpy(conf.toMain,value);
-			}	    
-		} else if (strcmp(tag,AUTOREPEAT_STR) == 0 && isInit) {
-			if (value != NULL && strncmp("true",value,4)==0) {
-				conf.autoRepeat=1;
-			}	    
-		} else if (strcmp(tag,CMER_ON_STR) == 0 && isInit) {
-			if(value!= NULL) {
-				strcpy(conf.cmerOn,value);
-			}	    
-		} else if (strcmp(tag,CMER_OFF_STR) == 0 && isInit) {
-			if(value!= NULL) {
-				strcpy(conf.cmerOff,value);
-			}	    
+                        if (!isInit) {		// If we goes here from Include() command, we did all we need
+                        	return EXIT_OK;
+                        }
 		} else if (isInit) {
-			if (strncmp("GuiApp",tag,6) != 0 &&
-			    strncmp("GuiDescription",tag,14) != 0) {	// Do not warn about GUI meta tags
+			if (strncmp("GuiApp",tag,6) != 0) {
 				printf("WARNING: Unknown tag in cfg file >%s<\n",tag);
 			}
 		}
@@ -1651,7 +1403,6 @@ int load_cfg(char *mfile, int isInit)
 	fclose(fp);
 
 	loadInternal();
-	
 
 	//printf("LOAD:%s OK\n",mfile);
 	return EXIT_OK;
