@@ -36,12 +36,11 @@
 //#define DEFAULT_DEVICE  "/dev/rfcomm0"	seems JSR-82 phones is more usable now
 #define DEFAULT_DEVICE  "bluetooth:19"
 
-#define ALARMS_SECTION_STR  "[Alarms]"
-#define ALIAS_SECTION_STR   "[Aliases]"
-#define KEYS_SECTION_STR    "[Keys]"
-#define MODE_END_STR        "[ModeEnd]"
-#define MODE_STR    	    "[Mode]"
-#define SECTION_END_STR     "[End]"
+#define KEYS_SECTION_STR     "[Keys]"
+#define PROTOCOL_SECTION_STR "[Protocol]"
+#define MODE_END_STR         "[ModeEnd]"
+#define MODE_STR    	     "[Mode]"
+#define SECTION_END_STR      "[End]"
 
 // Some AT stuff
 // \r will be added before send
@@ -78,6 +77,7 @@
 #define ID_EVT_EXIT	      2 	     
 #define ID_EVT_CONNECT        3 	     
 #define ID_EVT_DISCONNECT     4 	     
+#define ID_EVT_ENDCALL        5     
 
 #define EVT_INIT     	"(Init)"
 #define EVT_EXIT        "(Exit)"
@@ -104,6 +104,7 @@
 #define ID_GET          12
 #define ID_MAKE         13
 #define ID_EMU          14
+#define ID_DBUS         15
 
 #define CMD_EXIT    	        "Exit"
 #define CMD_EXEC                "Exec"
@@ -119,6 +120,7 @@
 #define CMD_GET             	"Get"      		// Server mode only      
 #define CMD_MAKE             	"Make" 
 #define CMD_EMU             	"Emulate" 
+#define CMD_DBUS             	"Dbus" 
 
 #define SET_BG         "bg"
 #define SET_PARAM      "parameter"
@@ -143,6 +145,7 @@
 
 #define MAKE_DISCONN    "disconnect"
 #define MAKE_MODE       "mode"
+#define MAKE_ALARM      "alarm"
 #define MAKE_FLUSH      "flush"
 #define MAKE_STOP       "stop"
 #define MAKE_REMOTE     "remote"
@@ -182,6 +185,10 @@
 #define FLAG_PARAMETR	 1
 #define FLAG_UNDEF	-3
 
+#define AUTOCONN_STR   	"AutoConnect"
+#define AUTOREPEAT_STR	"AutoRepeat"
+#define CHARSET_STR    	"CharSet"
+
 typedef struct Td
 {
 	//char       id[MAXARGLEN];
@@ -205,13 +212,6 @@ typedef struct Tk
         struct Tk   *next;
 } type_key;
 
-typedef struct Ta
-{
-	char       *key;
-        char       *alias;
-        struct Ta  *next;
-} type_alias;
-
 typedef struct Mt
 {
 	char        name[MTEXTLEN];
@@ -227,27 +227,21 @@ typedef struct Cp
 
 typedef struct
 {
-	int   log;
-        int   baudrate;
-        int   retrysecs;
-        int   screen;
-        int   autoConnect;              // AT mode only
-        int   autoRepeat;
-        char  charset   [MTEXTLEN];     // Charset - AT mode only
-        char  device    [MAXARGLEN];    // Device
-        char  toMain    [MTEXTLEN];     // AnyMenu  -> MainMenu - AT mode only
-        char  cmerOn    [MTEXTLEN];     // AT mode only
-        char  cmerOff   [MTEXTLEN];     // AT mode only
         int   model;
         char* cfgDir;
         int   frontEnd;
         int   http;
         int   pass;
-        char  serviceName[MTEXTLEN];
         uid_t   uid;
 	gid_t   gid;
 } CONF;
 
+typedef struct Ta
+{
+	char        *file;
+        char        *macro;
+        struct Ta   *next;
+} type_alarm;
 
 // Exported functions definitions
 
