@@ -24,9 +24,10 @@
 
 
 // Frontend support
-int connectFrontEnd(int portno);
-int sendToFrontEnd(char *buf);
-int disconnectFrontEnd(void);
-int readFromFrontEnd(char *buf, int size);
+gboolean frontendRoutine(gpointer data);
+int   connectFrontEnd	(int portno);
+void  sendToFrontEnd	(char *buf);
+void  disconnectFrontEnd(void);
+int   readFromFrontEnd	(char *buf, int size);
 
 #endif
