@@ -26,14 +26,15 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <pwd.h>
+#include <glib.h>
 
 #include "common.h"
 #include "utils.h"
 #include "conf.h"
 
-
-extern char tmp[MAXMAXLEN];
-extern CONF       conf;
+extern char         tmp[MAXMAXLEN];
+extern CONF         conf;
+extern GAsyncQueue* q2main;
 
 // Some globals
 
@@ -48,10 +49,11 @@ int    lastValuesSize[ID_SETMAX] = {-1};
 
 // used by Flush() command to temporary store old configuration
 static mode       *flushModes   = NULL;
-static type_alias *flushAliases = NULL;
-static type_key   *flushAlarms  = NULL;
+static type_alarm *flushAlarms  = NULL;
 
 
+GMutex * logMutex = NULL;
+
 //////////////////////////////////////////////////////////////////////////////////
 //
 // Functions related to logging
@@ -101,47 +103,49 @@ void initLog()
 			chown(logfile,conf.uid,conf.gid);
 		}
 
+		logMutex = g_mutex_new();
+		
                 printConf();
         }
 }
 
 void logger(char *head, char *str)
 {
+	//printf("logger ENTER\n");fflush(stdout);
 	FILE *fplog;
         time_t logtime;
 
-	if (logfile[0] == '\0') {
+	if (logfile[0] == '\0' || 
+	    (!getLog())        ||
+	    (strcmp(head, "DBG") == 0 && getDebug() == 0)) {
         	return;
         }
+	g_mutex_lock(logMutex);
+	
+        fplog = fopen(logfile, "a");
+        if (fplog!=NULL) {
+        	if (strcmp(head, "CFG") != 0) {
+                	time(&logtime);
+			struct tm* timeinfo = localtime (&logtime );
+			
+			char stime[32];
+			stime[8] = '\0';
+			
+			sprintf(stime, "%2d:%2d:%2d", timeinfo->tm_hour, timeinfo->tm_min, timeinfo->tm_sec);
+			fprintf(fplog, "[%s] - ",stime);
+                }   
+                if(head!=NULL) {
+                	fprintf(fplog, "%s - ",head);
+                }
+                fprintf(fplog, "%s\n",str);
         
-        if (getLog()) {
-        	
-                if (strcmp(head, "DEBUG") == 0 && getDebug() == 0) {
-                    return;
-                }
-
-                fplog = fopen(logfile, "a");
-                if (fplog!=NULL) {
-                	if (strcmp(head, "CFG") != 0) {
-                        	time(&logtime);
-				struct tm* timeinfo = localtime (&logtime );
-				
-				char stime[32];
-				stime[8] = '\0';
-				
-				sprintf(stime, "%2d:%2d:%2d", timeinfo->tm_hour, timeinfo->tm_min, timeinfo->tm_sec);
-				fprintf(fplog, "[%s] - ",stime);
-                        }   
-                        if(head!=NULL) {
-                        	fprintf(fplog, "%s - ",head);
-                        }
-                        fprintf(fplog, "%s\n",str);
-                
-                        fclose(fplog);
-                } else {
-                	printf("Can't open log file >%s<\n", logfile);
-                }
+                fclose(fplog);
+        } else {
+        	printf("Can't open log file >%s<\n", logfile);
         }
+	
+	g_mutex_unlock(logMutex);
+	//printf("logger EXIT\n");fflush(stdout);
 }
 
 void printTime()
@@ -151,10 +155,8 @@ void printTime()
 				
         char *timestr = (char *) ctime(&logtime);
         timestr[strlen(timestr)-1]=0;
-  	
 	logger("CFG", timestr);
 }	
-
 void setResFile()
 {
 	initFile(tofile, TOFILE);
@@ -192,12 +194,12 @@ timerCmd* findTimer(char *id, timerCmd **prev)
 timerCmd* createTimer(cmdItem *ci)
 {
 	if (ci->descr == NULL || ci->descr[0] == '\0' || ci->tdata == NULL) {
-        	logger("DEBUG", "createTimer(): wrong input");                
+        	logger("DBG", "createTimer(): wrong input");                
                 return NULL;
         }
 
         if (findTimer(ci->descr, NULL) != NULL) {
-        	logger("DEBUG", "createTimer(): timer already exists");                
+        	logger("DBG", "createTimer(): timer already exists");                
                 return NULL;
         } 
         timerCmd *tm = calloc(sizeof(timerCmd),1);
@@ -218,15 +220,15 @@ timerCmd* createTimer(cmdItem *ci)
         return tm;
 }
 
-int cancelTimer(char *id) 
+void cancelTimer(char *id) 
 {
 	DEBUG2("cancelTimer() >%s<", id);
 
         timerCmd *prev = NULL;
         timerCmd *tm = findTimer(id, (timerCmd **) &prev);
         if (tm == NULL) {
-            logger("DEBUG", "Cant find timer to cancel!");
-            return EXIT_NOK;
+        	logger("DBG", "Cant find timer to cancel!");
+        	return ;
         }    
         if (tm == timers) { //remove in head
         	timers = tm->next;
@@ -234,20 +236,20 @@ int cancelTimer(char *id)
         	if (prev != NULL) {
                 	prev->next = tm->next;
                 } else {
-                	logger("ERROR", "Previous item absent for non-first element");
-                        return EXIT_NOK;
+                	logger("ERR", "Previous item absent for non-first element");
+                        return;
                 }
         }       
          
 	tm->timer = NULL;
         free(tm);
 
-        return EXIT_OK;
+        return;
 }
 
 void freeTimers()
 {
-	logger("DEBUG", "freeTimers()");
+	logger("DBG", "freeTimers()");
         timerCmd *tm;
 
         while (timers != NULL) {
@@ -259,9 +261,9 @@ void freeTimers()
         }
 }
 
-extern int macroCmd(char *macro, cmdParams* params);
+extern void macroCmd(char *macro, cmdParams* params);
 
-int verifyTimers(int ticksInSec) 
+void verifyTimers(int ticksInSec) 
 {
 	timerCmd *tm   = timers;
 
@@ -270,10 +272,7 @@ int verifyTimers(int ticksInSec)
                 	if (tm->ticks >= (tm->timer->tdata->timeout * ticksInSec)) {
                 		DEBUG2("verifyTimers(): it is time to execute >%s<", (tm->timer->exec != NULL ? tm->timer->exec : "empty command"));
 
-				int ret = macroCmd(tm->timer->descr,NULL);
-               			if (ret == EXIT_ABORT || ret == EXIT_DISCON) {
-                        		return ret;
-                        	}
+				macroCmd(tm->timer->descr,NULL);
                 
                         	tm->ticks = 0;
                 
@@ -297,8 +296,6 @@ int verifyTimers(int ticksInSec)
                 }
                 tm   = tm->next;
         }
-	
-        return EXIT_OK;
 }
 
 //////////////////////////////////////////////////////////////////////////////////
@@ -357,10 +354,11 @@ varData* searchVar(const char *id, int len)
 	if (id == NULL || len <= 0) {
         	return NULL;
         }
+	/* infinite recursion on start-up
 	strcpy(tmp, "searchVar() >");
 	strncat(tmp,id,len);
 	strcat(tmp,"<");
-	logger("DEBUG", tmp);
+	logger("DBG", tmp);*/
 
 	varData* ptr = vars;
 
@@ -372,7 +370,7 @@ varData* searchVar(const char *id, int len)
 
 static int addVar(const char *name, const char *val, int sz)
 {
-	DEBUG2("addVar() >%s<", name);
+	//printf("addVar() >%s< >%s<\n", name,val);
                 
         varData * v = (varData *) calloc(sizeof(varData),1);
         v->name  = strdup(name);
@@ -409,15 +407,63 @@ void addInternalVars()
 	#else
         addVar("Xtest", "no", 2);	
 	#endif
+
 	
 	#ifdef USE_BLUEZ
         addVar("Bluez", "yes", 3);	
 	#else
         addVar("Bluez", "no", 2);	
 	#endif
+
+	#ifdef USE_DBUS
+        addVar("Dbus", "yes", 3);	
+	#else
+        addVar("Dbus", "no", 2);	
+	#endif
         
 	addVar("MixerCard",    "0",      1);	
-        addVar("MixerChannel", "Master", 6);	
+        addVar("MixerChannel", "Master", 6);
+	
+	// Former "parameters"	
+	addVar("AutoConnect",  "false",  5);	
+        addVar("AutoRepeat",   "false",  5);
+	addVar("Baudrate",     "19200",  5);
+	addVar("CharSet",      "8859-1", 6);			// AT mode only
+	addVar("CmerOff",      "",       0);	   		// AT mode only
+	addVar("CmerOn",       "",       0);			// AT mode only
+	addVar("Device",       "bluetooth:19", 12);
+	addVar("Logging",      "false",  5);
+	addVar("RetrySeconds", "60",     2);
+	addVar("ServiceName",  "anyRemote",    10);
+	addVar("TwoWayComm",   "false",  5);			// Send something to device ?
+	addVar("ToMainMenu",   "E",      1);			// AnyMenu  -> MainMenu - AT mode only
+}
+
+void printVars() 
+{
+	sprintf(tmp, "[Variables]");
+	logger("CFG", tmp);
+	
+	varData* ptr = vars;
+        while (ptr != NULL) {	
+		
+		// value of variable can contain \0 inside
+		memset(tmp, 0, MAXMAXLEN);
+		sprintf(tmp, "\t%s \t-> ", ptr->name);
+		strncat(tmp, ptr->value != NULL ? ptr->value : "(empty)",ptr->value != NULL ? ptr->size : 7);
+		logger("CFG", tmp);
+               
+	        ptr  = ptr->next;
+        }
+	sprintf(tmp, "[End]");
+	logger("CFG", tmp);
+}
+
+// can be used only to _string_ data 
+// (binary data can contain \0 inside)
+int setVarSimple(const char *name, const char* val)
+{
+	return setVar(name, val, strlen(val));
 }
 
 int setVar(const char *name, const char *val, int sz)
@@ -426,12 +472,13 @@ int setVar(const char *name, const char *val, int sz)
               return EXIT_NOK;
         }
 	DEBUG2("setVar() >%s->%s<", name, (val == NULL ? "NULL" : val));
-        
+ 	//printf("setVar() >%s->%s<", name, (val == NULL ? "NULL" : val));
+       
 	varData * v = searchVar(name, strlen(name));
         if (v == NULL) {		// Add variable if it not yet defined
         	return addVar(name, val, sz);
         }
-	
+
         // Store new value in already defined variable
 	if (v->value != NULL) {
         	free(v->value);v->value = NULL;
@@ -449,7 +496,7 @@ int setVar(const char *name, const char *val, int sz)
  
 void freeVars()
 {
-	//logger("DEBUG", "freeVars()");
+	//logger("DBG", "freeVars()");
         varData *vv;
 
         while (vars != NULL) {
@@ -473,16 +520,14 @@ void freeVars()
 
 extern mode       *currentMode;
 extern mode       *modes;
-extern type_alias *aliases;
-extern type_key   *alarms;
+extern type_alarm *alarms;
 
 extern int  flushConf;
 
 void printHelp() 
 {
-	printf("Usage: anyremote [-f conf.file] [-s connect string] [-b baudrate] [-log] [-n] [-a] \n");
-	printf("                 [-fe port] [-http] [-u username] [-name SDP service name]\n");
-	//printf("   or: anyremote -h|-v|-getconfdir\n");
+	printf("Usage: anyremote [-f conf.file] [-s connect string] [-log] [-a] \n");
+	printf("                 [-fe port] [-http] [-u username] [-name SDP service name] [-password]\n");
 	printf("   or: anyremote -h|-v\n\n");
 	printf(" -h|--help  print this help\n");
 	printf(" -v|--version  print version of anyRemote\n");
@@ -497,8 +542,6 @@ void printHelp()
 	printf("    ilirc:<AF_LOCAL socket file> (use with inputlircd)\n");
 	printf("    stdin\n");
 	printf(" -log	print verbose logging information to $HOME/.anyRemote/anyremote.log\n");
-	printf(" -b	baudrate: specify baudrate, default is 19200\n");
-	printf(" -n	do not send any AT+CKPD command to the phone\n");
 	printf(" -a	reconnect automatically in case of connection failure\n");
 	printf(" -fe <port> work as backend for GUI frontend. Use specified port to connect to frontend.\n");
 	printf(" -http  tune work with anyremote2html\n");
@@ -516,15 +559,12 @@ void printHelp()
 
 int flushData() 
 {
-	//logger("DEBUG","flushData");
+	//logger("DBG","flushData");
         
         flushConf = 1;
         
         flushModes = modes;
         modes = NULL;
-        
-        flushAliases = aliases;
-        aliases = NULL;
 
         flushAlarms = alarms;
         alarms = NULL;
@@ -540,10 +580,9 @@ int flushData()
 void flushOldConf() {
 
 	freeTimers();
-        freeCfgEx(flushModes, flushAlarms, flushAliases);
+        freeCfgEx(flushModes, flushAlarms);
         flushModes   = NULL;
         flushAlarms  = NULL;
-        flushAliases = NULL;
 }
 
 int getUidGid(char *username, uid_t *uid, gid_t *gid) {
@@ -603,5 +642,28 @@ char* getStoredPass()
 	return fBuffer;
 }
 
+static void sendToMainThread(int *m)
+{
+	if (q2main == NULL || m == NULL) {
+		return;
+	}
+	
+	g_async_queue_push(q2main,m);
+	return;
+}
+
+void sendAbort()
+{
+	int* i = malloc(sizeof(int));
+	*i = M_ABORT;
+	sendToMainThread(i);
+}
+
+void sendDisconnect()
+{
+	int* i = malloc(sizeof(int));
+	*i = M_DISCONNECT;
+	sendToMainThread(i);
+}
 
 //////////////////////////////////////////////////////////////////////////////////
