@@ -31,11 +31,15 @@
 #define TIMER_RUN       1
 #define TIMER_PAUSE     2
 
-#define CFG2(...)     sprintf(tmp,__VA_ARGS__);logger("CFG",     tmp);
-#define DEBUG2(...)   sprintf(tmp,__VA_ARGS__);logger("DEBUG",   tmp);
-#define ERROR2(...)   sprintf(tmp,__VA_ARGS__);logger("ERROR",   tmp);
-#define INFO2(...)    sprintf(tmp,__VA_ARGS__);logger("INFO",    tmp);
-#define WARNING2(...) sprintf(tmp,__VA_ARGS__);logger("WARNING", tmp);
+#define CFG2(...)     sprintf(tmp,__VA_ARGS__);logger("CFG", tmp);
+#define DEBUG2(...)   sprintf(tmp,__VA_ARGS__);logger("DBG", tmp);
+#define ERROR2(...)   sprintf(tmp,__VA_ARGS__);logger("ERR", tmp);
+#define INFO2(...)    sprintf(tmp,__VA_ARGS__);logger("INF", tmp);
+#define WARNING2(...) sprintf(tmp,__VA_ARGS__);logger("WRN", tmp);
+
+#define M_ABORT 	0
+#define M_DISCONNECT 	1
+#define M_DEV_DISCONN 	2
 
 typedef struct TC
 {	
@@ -59,15 +63,17 @@ typedef struct VV
 
 void        printHelp       (void);
 void        printTime       (void);
+void        printVars       (void);
 void        initLog         (void);
 void        logger          (char *head, char *str);
 
 timerCmd*   createTimer     (cmdItem *ci);
 timerCmd*   findTimer       (char *id, timerCmd **prev);
-int         verifyTimers    (int ticksInSec);
-int         cancelTimer     (char *id);
+void        verifyTimers    (int ticksInSec);
+void        cancelTimer     (char *id);
 void        freeTimers      (void);
 
+int         setVarSimple    (const char *name, const char *val);
 int         setVar          (const char *name, const char *val, int size);
 varData*    searchVar       (const char *id, int len);
 void        freeVars        (void);
@@ -86,4 +92,7 @@ int         getUidGid       (char *username, uid_t *uid, gid_t *gid);
 char* 	    getStoredPass   (void);
 void 	    addInternalVars (void);
 
+void  	    sendAbort       (void);
+void        sendDisconnect  (void);
+
 #endif
